@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2016
+  Copyright (c) 1998 - 2018
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -32,7 +32,7 @@
 
 int main( int argc, const char *argv[]) {
   TiCC::CL_Options opts( Tagger::mbt_short_opts + "S:",
-			 Tagger::mbt_long_opts + ",config:,logfile:,pidfile:,daemonize:" );
+			 Tagger::mbt_long_opts + ",debug,config:,logfile:,pidfile:,daemonize:" );
   opts.init( argc, argv );
   MbtServer::StartServer( opts );
   exit(EXIT_SUCCESS);
